@@ -6,6 +6,7 @@
 
 import numpy as np
 import warnings
+import os
 from astropy.io import fits
 from astropy.time import Time
 from peewee import JOIN
@@ -21,6 +22,9 @@ from mugatu.designs_to_targetdb import (make_design_assignments_targetdb,
                                         make_design_field_targetdb)
 from mugatu.designmode import DesignModeCheck
 
+import robostrategy.obstime as obstime
+import coordio.time
+
 try:
     from sdssdb.peewee.sdss5db import database
     database.set_profile('operations')
@@ -31,7 +35,8 @@ except:
 from sdssdb.peewee.sdss5db.targetdb import (Design, Field, Observatory,
                                             Assignment, Instrument, Target,
                                             Hole, CartonToTarget, Carton,
-                                            Magnitude, Category)
+                                            Magnitude, Category, DesignToField,
+                                            Version)
 
 
 class FPSDesign(object):
@@ -144,6 +149,12 @@ class FPSDesign(object):
         only 1 exposure in the design file. if exp>0, then will
         choose exposure exp = 1 to N.
 
+    RS_VERSION: str
+        The version of targetdb to get designs from. If None will
+        look for RS_VERSION enviornment variable, and if None exists
+        will default to first entry in DesignToField for that
+        design_id.
+
     Attributes
     ----------
     design: dict
@@ -186,19 +197,19 @@ class FPSDesign(object):
         dictonary with errors for design. Created and filled after validation.
     """
 
-    def __init__(self, design_pk, obsTime, racen=None, deccen=None,
+    def __init__(self, design_pk, obsTime=None, racen=None, deccen=None,
                  position_angle=None, observatory=None, desmode_label=None,
                  idtype='carton_to_target', catalogids=None, ra=None, dec=None,
                  pmra=None, pmdec=None, delta_ra=None, delta_dec=None,
                  epoch=None, holeID=None, obsWavelength=None,
                  priority=None, carton_pk=None, category=None, magnitudes=None,
-                 design_file=None, manual_design=False, exp=0):
+                 design_file=None, manual_design=False, exp=0, RS_VERSION=None):
         if idtype != 'catalogID' and idtype != 'carton_to_target':
             message = 'idtype must be catalogID or carton_to_target'
             raise MugatuError(message=message)
         self.design_pk = design_pk
-        self.obsTime = obsTime
         self.design = {}
+        self.RS_VERSION = RS_VERSION
         # either set field params or pull from db is design
         # is in targetdb
         if manual_design:
@@ -217,18 +228,59 @@ class FPSDesign(object):
                 self.observatory = head['obs'].strip().upper()
                 self.desmode_label = desmode_labels[exp - 1]
         else:
-            design_field_db = (
-                Design.select(Design.design_id,
-                              Design.design_mode,
-                              Field.racen,
-                              Field.deccen,
-                              Field.position_angle,
-                              Observatory.label)
-                      .join(Field,
-                            on=(Design.field_pk == Field.pk))
-                      .join(Observatory,
-                            on=(Field.observatory == Observatory.pk))
-                      .where(Design.design_id == self.design_pk))
+            if self.RS_VERSION is None:
+                self.RS_VERSION = os.getenv('RS_VERSION')
+                if self.RS_VERSION is None:
+                    design_field_db = (
+                        Design.select(Design.design_id,
+                                      Design.design_mode,
+                                      Field.racen,
+                                      Field.deccen,
+                                      Field.position_angle,
+                                      Observatory.label)
+                              .join(DesignToField,
+                                    on=(Design.design_id == DesignToField.design))
+                              .join(Field,
+                                    on=(DesignToField.field == Field.pk))
+                              .join(Observatory,
+                                    on=(Field.observatory == Observatory.pk))
+                              .where(Design.design_id == self.design_pk))
+                else:
+                    design_field_db = (
+                        Design.select(Design.design_id,
+                                      Design.design_mode,
+                                      Field.racen,
+                                      Field.deccen,
+                                      Field.position_angle,
+                                      Observatory.label)
+                              .join(DesignToField,
+                                    on=(Design.design_id == DesignToField.design))
+                              .join(Field,
+                                    on=(DesignToField.field == Field.pk))
+                              .join(Observatory,
+                                    on=(Field.observatory == Observatory.pk))
+                              .switch(Field)
+                              .join(Version,
+                                    on=(Field.version == Version.pk))
+                              .where((Design.design_id == self.design_pk) &
+                                     (Version.plan == self.RS_VERSION)))
+                    if len(design_field_db) == 0:
+                        flag = 'Design not in set RS_VERSION.'
+                        warnings.warn(flag, MugatuWarning)
+                        design_field_db = (
+                            Design.select(Design.design_id,
+                                          Design.design_mode,
+                                          Field.racen,
+                                          Field.deccen,
+                                          Field.position_angle,
+                                          Observatory.label)
+                                  .join(DesignToField,
+                                        on=(Design.design_id == DesignToField.design))
+                                  .join(Field,
+                                        on=(DesignToField.field == Field.pk))
+                                  .join(Observatory,
+                                        on=(Field.observatory == Observatory.pk))
+                                  .where(Design.design_id == self.design_pk))
 
             self.racen = design_field_db.objects()[0].racen
             self.deccen = design_field_db.objects()[0].deccen
@@ -255,6 +307,11 @@ class FPSDesign(object):
         self.design_file = design_file
         self.manual_design = manual_design
         self.exp = exp
+        if obsTime is None:
+            ot = obstime.ObsTime(observatory=self.observatory.lower())
+            self.obsTime = coordio.time.Time(ot.nominal(lst=self.racen)).jd
+        else:
+            self.obsTime = obsTime
 
         # set dummy value for collision for now
         # this may want to be a input, not sure the standard here
@@ -422,7 +479,7 @@ class FPSDesign(object):
         self.design['obsWavelength'] = np.zeros(500, dtype='<U6')
         self.design['priority'] = np.zeros(500, dtype=int) - 1
         self.design['carton_pk'] = np.zeros(500, dtype=int) - 1
-        self.design['category'] = np.zeros(500, dtype='<U10')
+        self.design['category'] = np.zeros(500, dtype='<U20')
         self.design['ra'] = np.zeros(500, dtype=float) - 9999.99
         self.design['dec'] = np.zeros(500, dtype=float) - 9999.99
         self.design['delta_ra'] = np.zeros(500, dtype=float) - 9999.99
@@ -951,7 +1008,7 @@ class FPSDesign(object):
         self.valid_design['obsWavelength'] = np.zeros(500, dtype='<U6')
         self.valid_design['priority'] = np.zeros(500, dtype=int) - 1
         self.valid_design['carton_pk'] = np.zeros(500, dtype=int) - 1
-        self.valid_design['category'] = np.zeros(500, dtype='<U10')
+        self.valid_design['category'] = np.zeros(500, dtype='<U20')
         self.valid_design['ra'] = np.zeros(500, dtype=float) - 9999.99
         self.valid_design['dec'] = np.zeros(500, dtype=float) - 9999.99
         self.valid_design['pmra'] = np.zeros(500, dtype=float) - 9999.99
@@ -1124,6 +1181,7 @@ class FPSDesign(object):
             plan='manual',
             fieldid=fieldid,
             exposure=exposure,
+            field_exposure=field_exposure,
             desmode_label=self.desmode_label,
             catalogID=self.valid_design['catalogID'][self.valid_design['catalogID'] != -1],
             robotID=self.valid_design['robotID'][self.valid_design['catalogID'] != -1],
